==> antlr-java-parser-1.0.2-sources.jar: com/github/antlrjavaparser/adapter/QualifiedNameListContextAdapter.java <==
/*
 * This file is part of antlr-java-parser.
 *
 *     antlr-java-parser is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     antlr-java-parser is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with antlr-java-parser.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.github.antlrjavaparser.adapter;

import com.github.antlrjavaparser.Java7Parser;
import com.github.antlrjavaparser.api.expr.NameExpr;

import java.util.LinkedList;
import java.util.List;

public class QualifiedNameListContextAdapter implements Adapter<List<NameExpr>, Java7Parser.QualifiedNameListContext> {
    public List<NameExpr> adapt(Java7Parser.QualifiedNameListContext context) {

        if (context == null) {
            return null;
        }

        List<NameExpr> nameExprList = new LinkedList<NameExpr>();
        for (Java7Parser.QualifiedNameContext qualifiedNameContext : context.qualifiedName()) {
            nameExprList.add(Adapters.getQualifiedNameContextAdapter().adapt(qualifiedNameContext));
        }

        return nameExprList;
    }
}

==> antlr-java-parser-1.0.9-sources.jar: com/github/antlrjavaparser/adapter/QualifiedNameListContextAdapter.java <==
/*
 * This file is part of antlr-java-parser.
 *
 *     antlr-java-parser is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     antlr-java-parser is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with antlr-java-parser.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.github.antlrjavaparser.adapter;

import com.github.antlrjavaparser.Java7Parser;
import com.github.antlrjavaparser.api.expr.NameExpr;

import java.util.LinkedList;
import java.util.List;

public class QualifiedNameListContextAdapter implements Adapter<List<NameExpr>, Java7Parser.QualifiedNameListContext> {
    public List<NameExpr> adapt(Java7Parser.QualifiedNameListContext context, AdapterParameters adapterParameters) {

        if (context == null) {
            return null;
        }

        List<NameExpr> nameExprList = new LinkedList<NameExpr>();
        for (Java7Parser.QualifiedNameContext qualifiedNameContext : context.qualifiedName()) {
            nameExprList.add(Adapters.getQualifiedNameContextAdapter().adapt(qualifiedNameContext, adapterParameters));
        }

        return nameExprList;
    }
}
